# fireorm-repository

# Описание
    Базовый репозиторий для выполнения запросов к Firestore

# Зависимости
    Python, Pip
    Файл доступа к Firestore

# Установка
    pip install fireorm-repository